#
# spec file for package python-mohawk
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-mohawk
Version:        1.1.0
Release:        6.1
Summary:        Library for Hawk HTTP authorization
License:        MPL-2.0
URL:            https://github.com/kumar303/mohawk
Source:         https://files.pythonhosted.org/packages/source/m/mohawk/mohawk-%{version}.tar.gz
Patch0:         remove-nose.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
Mohawk is an alternate Python implementation of the Hawk HTTP
authorization scheme.

%prep
%autosetup -p1 -n mohawk-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest

%files %{python_files}
%doc README.rst
%{python_sitelib}/mohawk
%{python_sitelib}/mohawk-%{version}*-info

%changelog
* Mon Jun  2 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Tue Aug  2 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on mock.
- Remove bcond for running tests.
* Thu Mar 24 2022 pgajdos@suse.com
- Extend remove-nose.patch: Use unittest.mock instead of
  python-mock (https://trello.com/c/S6eADbii/64-remove-python-mock)
* Thu Sep 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-nose.patch:
  * Use unittest assert methods rather than requiring nose.
* Fri Feb 19 2021 antoine.belvire@opensuse.org
- Replace call to 'python setup.py test' by pyunittest macro: This
  prevents a DeprecationWarning turned into an error from failing
  the build.
* Mon Oct 28 2019 antoine.belvire@opensuse.org
- Update to version 1.1.0:
  * Support passing file-like objects (those implementing .read(n))
    as the content parameter for Resources. See mohawk.Sender for
    details.
* Fri Jan 11 2019 antoine.belvire@opensuse.org
- Update to version 1.0.0:
  * Security related: Bewit MACs were not compared in constant time
    and were thus possibly circumventable by an attacker.
  * Breaking change: Escape characters in header values (such as a
    back slash) are no longer allowed, potentially breaking clients
    that depended on this behavior.
  * A sender is allowed to omit the content hash as long as their
    request has no content. The `mohawk.Receiver` will skip the
    content hash check in this situation, regardless of the value
    of accept_untrusted_content.
  * Introduced max limit of 4096 characters in the Authorization
    header.
  * Changed default values of content and content_type arguments to
    `mohawk.base.EmptyValue` in order to differentiate between
    misconfiguration and cases where these arguments are explicitly
    given as None (as with some web frameworks).
  * Failing to pass content and content_type arguments to
    `mohawk.Receiver` or `mohawk.Sender.accept_response` without
    specifying accept_untrusted_content=True will now raise
    `mohawk.exc.MissingContent` instead of `ValueError`.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Dec  2 2017 antoine.belvire@opensuse.org
- Initial package: python-mohawk 0.3.4.
